# coding: utf-8

"""
    AI Decision Protocol

    AI Decision Protocol Specification

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr
from aitp.stubs.models.request_decision_request_decision import RequestDecisionRequestDecision

class RequestDecision(BaseModel):
    """
    RequestDecision
    """
    var_schema: StrictStr = Field(default=..., alias="$schema")
    request_decision: RequestDecisionRequestDecision = Field(...)
    additional_properties: Dict[str, Any] = {}
    __properties = ["$schema", "request_decision"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RequestDecision:
        """Create an instance of RequestDecision from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of request_decision
        if self.request_decision:
            _dict['request_decision'] = self.request_decision.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RequestDecision:
        """Create an instance of RequestDecision from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RequestDecision.parse_obj(obj)

        _obj = RequestDecision.parse_obj({
            "var_schema": obj.get("$schema"),
            "request_decision": RequestDecisionRequestDecision.from_dict(obj.get("request_decision")) if obj.get("request_decision") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


